@@ -76,6 +76,13 @@ class I2C(Lockable):
                 I2C_ItsyBitsy as _I2C,
             )
 
+            self._i2c = _I2C(scl, sda, frequency=frequency)
+            return
+        if detector.board.macropad_u2if:
+            from adafruit_blinka.microcontroller.rp2040_u2if.i2c import (
+                I2C_MacroPad as _I2C,
+            )
+
             self._i2c = _I2C(scl, sda, frequency=frequency)
             return
         if detector.board.qt2040_trinkey_u2if:
@@ -237,6 +244,14 @@ class SPI(Lockable):
                 SPI_ItsyBitsy as _SPI,
             )
 
+            self._spi = _SPI(clock)  # this is really all that's needed
+            self._pins = (clock, clock, clock)  # will determine MOSI/MISO from clock
+            return
+        if detector.board.macropad_u2if:
+            from adafruit_blinka.microcontroller.rp2040_u2if.spi import (
+                SPI_MacroPad as _SPI,
+            )
+
             self._spi = _SPI(clock)  # this is really all that's needed
             self._pins = (clock, clock, clock)  # will determine MOSI/MISO from clock
             return
@@ -306,6 +321,10 @@ class SPI(Lockable):
             from adafruit_blinka.microcontroller.rp2040_u2if.spi import (
                 SPI_ItsyBitsy as _SPI,
             )
+        elif detector.board.macropad_u2if:
+            from adafruit_blinka.microcontroller.rp2040_u2if.spi import (
+                SPI_MacroPad as _SPI,
+            )
         elif detector.board.qtpy_u2if:
             from adafruit_blinka.microcontroller.rp2040_u2if.spi import SPI_QTPY as _SPI
         elif detector.chip.id == ap_chip.RP2040:
